@@ -25,7 +25,7 @@
 #
 # HUBzero is a registered trademark of The Regents of the University of California.
 #
-__version__ = '3.8.1'
+__version__ = '3.11.1'
 
 import sys
 import os
@@ -37,14 +37,20 @@ import logging
 from errno import EPIPE
 
 from hubzero.submit.CommandParser    import CommandParser
+from hubzero.submit.DaemonsInfo      import DaemonsInfo
 from hubzero.submit.RemoteJobMonitor import RemoteJobMonitor
 
 class JobKill:
    def __init__(self,
-                listenURI):
+                daemonsDirectory,
+                daemonsConfigurationFile):
       self.logger           = logging.getLogger(__name__)
       self.version          = __version__
       self.operationMode    = 0
+
+      configFilePath        = os.path.join(daemonsDirectory,daemonsConfigurationFile)
+      daemonsInfo           = DaemonsInfo(configFilePath)
+      listenURI             = daemonsInfo.getDaemonListenURI('jobMonitor','tcp')
       self.remoteJobMonitor = RemoteJobMonitor(listenURI)
 
       self.commandParser        = None
